# Changelog

All notable changes to this project will be documented in this file.

The format is based on [Keep a Changelog](https://keepachangelog.com/en/1.0.0/),
and this project adheres to [Semantic Versioning](https://semver.org/spec/v2.0.0.html).

## [Unreleased]

## [0.1.3](https://github.com/agntcy/agp/compare/agp-tracing-v0.1.2...agp-tracing-v0.1.3) - 2025-03-18

### Added

- propagate context to enable distributed tracing ([#90](https://github.com/agntcy/agp/pull/90))

## [0.1.2](https://github.com/agntcy/agp/compare/agp-tracing-v0.1.1...agp-tracing-v0.1.2) - 2025-02-28

### Added

- add message handling metrics

## [0.1.1](https://github.com/agntcy/agp/compare/agp-tracing-v0.1.0...agp-tracing-v0.1.1) - 2025-02-14

### Added

- implement opentelemetry tracing subscriber

## [0.1.0](https://github.com/agntcy/agp/releases/tag/agp-tracing-v0.1.0) - 2025-02-10

### Added

- Stage the first commit of the agent gateway protocol (#3)

### Other

- reduce the number of crates to publish (#10)
